@@ -25,6 +25,7 @@
 #include <libglademm.h>
 #include <glom/libglom/data_structure/layout/layoutitem_button.h>
 #include "../base_db.h"
+#include <gtksourceviewmm/sourceview.h>
 
 namespace Glom
 {
@@ -40,11 +41,13 @@ public:
 
   void set_script(const sharedptr<const LayoutItem_Button>& script, const Glib::ustring& table_name);
   sharedptr<LayoutItem_Button> get_script() const;
+  void get_script (const sharedptr<LayoutItem_Button>& script) const;
 
 protected:
   void on_button_test();
 
-  Gtk::TextView* m_text_view;
+  Gtk::Entry* m_entry_title;
+  gtksourceview::SourceView* m_text_view;
   Gtk::Button* m_button_test;
 
   sharedptr<LayoutItem_Button> m_script;
