@@ -27,6 +27,7 @@
 #include <glom/libglom/data_structure/layout/layoutitem_field.h>
 
 #include <gtkmm/dialog.h>
+#include <gtkmm/messagedialog.h>
 
 namespace Glom
 {
@@ -38,6 +39,12 @@ typedef std::list<type_pair_sort_field> type_sort_clause;
 namespace Utils
 {
 
+///A standard widget spacing:
+extern const unsigned int DEFAULT_SPACING_LARGE;
+
+///A standard widget spacing:
+extern const unsigned int DEFAULT_SPACING_SMALL;
+
 Glib::ustring trim_whitespace(const Glib::ustring& text);
 
 Glib::ustring string_replace(const Glib::ustring& src, const Glib::ustring search_for, const Glib::ustring& replace_with);
@@ -73,8 +80,10 @@ Glib::ustring locale_language_id(const Glib::ustring& locale_id);
 
 Glib::ustring create_local_image_uri(const Gnome::Gda::Value& value);
 
+/** Get a decimal text representation of the number,
+ * in the current locale.
+ */
 Glib::ustring string_from_decimal(guint decimal);
-guint decimal_from_string(const Glib::ustring& str);
 
 /** Create an appropriate title for an ID string.
  * For instance, date_of_birth would become Date Of Birth.
@@ -90,7 +99,10 @@ Glib::ustring string_remove_suffix(const Glib::ustring& str, const Glib::ustring
 
 int dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id = Glib::ustring());
 
-void show_help (const Glib::ustring& id = Glib::ustring());
+void show_help(const Glib::ustring& id = Glib::ustring());
+
+void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type);
+
 } //namespace Utils
 
 } //namespace Glom
