@@ -21,10 +21,15 @@
 #ifndef BOX_DATA_DETAILS_H
 #define BOX_DATA_DETAILS_H
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
 #include "box_data.h"
 //#include "box_data_list_related.h"
+#include "flowtablewithfields.h"
 #include "../utility_widgets/placeholder.h"
-#include "../utility_widgets/flowtablewithfields.h"
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+#include "../utility_widgets/dragbar.h"
+#endif
 
 namespace Glom
 {
@@ -41,15 +46,7 @@ public:
 
   virtual void print_layout();
 
-  virtual Gnome::Gda::Value get_primary_key_value() const; //Actual primary key value of this record.
-  virtual Gnome::Gda::Value get_primary_key_value_selected(); //Value in the primary key's cell.
-
-  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& /* row */, const Gnome::Gda::Value& value);
-
-  virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
-  virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
-  virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
-
+ 
   //Signals:
   typedef sigc::signal<void> type_signal_void;
   type_signal_void signal_nav_first();
@@ -57,7 +54,7 @@ public:
   type_signal_void signal_nav_next();
   type_signal_void signal_nav_last();
 
-  typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_record_deleted; //arg is PrimaryKey.   //TODO: pass by const ref?
+  typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_record_deleted; //arg is PrimaryKey.
   type_signal_record_deleted signal_record_deleted();
 
    /** For instance,
@@ -67,11 +64,24 @@ public:
   type_signal_requested_related_details signal_requested_related_details();
 
 protected:
+
+
+  //Implementations of pure virtual methods from Base_DB_Table_Data:
+  virtual Gnome::Gda::Value get_primary_key_value_selected() const; //Value in the primary key's cell.
+  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
+  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const; //Actual primary key value of this record.
+    
+  virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
+  virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+  virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+
+
   virtual bool fill_from_database(); //override.
   virtual void create_layout();
   //virtual void fill_related();
 
   virtual sharedptr<Field> get_field_primary_key() const;
+  void set_found_set_from_primary_key_value();
 
   void print_layout_group(xmlpp::Element* node_parent, const sharedptr<const LayoutGroup>& group);
 
@@ -85,7 +95,10 @@ protected:
   virtual void on_button_nav_last();
 
   virtual void on_userlevel_changed(AppState::userlevels user_level); //override
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void on_flowtable_layout_changed();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   //Signal handler: The last 2 args are bind-ed.
   virtual void on_related_record_added(Gnome::Gda::Value key_value, Glib::ustring strFromKeyName);
@@ -102,14 +115,23 @@ protected:
 
   virtual void recalculate_fields_for_related_records(const Glib::ustring& relationship_name);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  virtual Dialog_Layout* create_layout_dialog() const; // override.
+  virtual void prepare_layout_dialog(Dialog_Layout* dialog); // override.
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   sharedptr<Field> m_field_primary_key;
   Gnome::Gda::Value m_primary_key_value;
 
   //Member widgets:
   Gtk::ScrolledWindow m_ScrolledWindow;
   Gtk::HBox m_HBox;
+  Gtk::HBox m_HBox_Sidebar;
   Gtk::Button m_Button_New;
   Gtk::Button m_Button_Del;
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  DragBar m_Dragbar;
+#endif
 
   /*
   Gtk::Frame m_Frame_Related;
@@ -135,6 +157,10 @@ protected:
 
   type_signal_record_deleted m_signal_record_deleted;
   type_signal_requested_related_details m_signal_requested_related_details;
+  
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  bool m_design_mode; // Cache here because we need it when the layout is redrawn
+#endif
 };
 
 } //namespace Glom
