@@ -36,6 +36,13 @@ Dialog_Layout_List::Dialog_Layout_List(BaseObjectType* cobject, const Glib::RefP
   //These do not make sense in a list:
   m_button_add_notebook->hide();
   m_button_add_related->hide();
+  m_button_add_related_calendar->hide();
+
+  //We don't want this part of the dialog:
+  //(We share one glade definition for several dialogs.)
+  Gtk::Frame* box_calendar = 0;
+  refGlade->get_widget("frame_calendar", box_calendar); 
+  box_calendar->hide();
 }
 
 Dialog_Layout_List::~Dialog_Layout_List()
