@@ -22,7 +22,7 @@
 #define GLOM_UTILITY_WIDGETS_BUTTON_GLOM_H
 
 #include <gtkmm.h>
-#include "layoutwidgetbase.h"
+#include "layoutwidgetutils.h"
 #include <glom/libglom/data_structure/layout/layoutitem_button.h>
 #include <libglademm.h>
 
@@ -33,7 +33,7 @@ class App_Glom;
 
 class ButtonGlom
 : public Gtk::Button,
-  public LayoutWidgetBase
+  public LayoutWidgetUtils
 {
 public:
   explicit ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
@@ -44,6 +44,9 @@ protected:
   void init();
 
   virtual App_Glom* get_application();
+    
+  virtual void on_menu_properties_activate();
+  virtual bool on_button_press_event(GdkEventButton *event);
 };
 
 } //namespace Glom
